==> haskell-temporary-1.2.0.3-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-temporary/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: temporary
version: 1.2.0.3
id: temporary-1.2.0.3-b5b73129fd6736489027821bdd88e94a
key: tempo_0xAihPa8DlS0pBf9k1EX73
license: BSD3
copyright: (c) 2003-2006, Isaac Jones
           (c) 2005-2009, Duncan Coutts
maintainer: Max Bolingbroke <batterseapower@hotmail.com>
homepage: http://www.github.com/batterseapower/temporary
synopsis: Portable temporary file and directory support for Windows and Unix, based on code from Cabal
description:
    The functions for creating temporary files and directories in the base library are quite limited. The unixutils
    package contains some good ones, but they aren'\''t portable to Windows.
    This library just repackages the Cabal implementations of its own temporary file and folder functions so that
    you can use them without linking against Cabal or depending on it being installed.
category: System, Utils
author: Isaac Jones <ijones@syntaxpolice.org>
        Duncan Coutts <duncan@haskell.org>
exposed: True
exposed-modules:
    System.IO.Temp
hidden-modules: Distribution.Compat.Exception
                Distribution.Compat.TempFile
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/temporary-1.2.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/temporary-1.2.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/temporary-1.2.0.3
hs-libraries: HStemporary-1.2.0.3-0xAihPa8DlS0pBf9k1EX73
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
haddock-interfaces: /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html: /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-temporary-1.2.0.4-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-temporary/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: temporary
version: 1.2.0.4
id: temporary-1.2.0.4-82bc44ff7d47fd2873d477b044a2a6ac
key: tempo_2Vjx9uYRKo19DPw0nApVnO
license: BSD3
copyright: (c) 2003-2006, Isaac Jones
           (c) 2005-2009, Duncan Coutts
maintainer: Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>
homepage: http://www.github.com/feuerbach/temporary
synopsis: Portable temporary file and directory support for Windows and Unix, based on code from Cabal
description:
    The functions for creating temporary files and directories in the base library are quite limited. The unixutils
    package contains some good ones, but they aren'\''t portable to Windows.
    This library just repackages the Cabal implementations of its own temporary file and folder functions so that
    you can use them without linking against Cabal or depending on it being installed.
category: System, Utils
author: Isaac Jones <ijones@syntaxpolice.org>
        Duncan Coutts <duncan@haskell.org>
exposed: True
exposed-modules:
    System.IO.Temp
hidden-modules: Distribution.Compat.Exception
                Distribution.Compat.TempFile
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/temporary-1.2.0.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/temporary-1.2.0.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/temporary-1.2.0.4
hs-libraries: HStemporary-1.2.0.4-2Vjx9uYRKo19DPw0nApVnO
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
haddock-interfaces: /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html: /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
